---
name: Bug report
about: Create a report to help us improve
title: "[BUG]"
labels: 'Type: bug'
assignees: steven-murray

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1.
2.

**Expected behavior**
A clear and concise description of what you expected to happen.

 - OS: [e.g. Ubuntu]
 - Version [e.g. 3.1.0]

**Additional context**
Add any other context about the problem here.
